SystemOrganization addCategory: #GODBasesTests!

TestCase subclass: #GDBDataTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODBasesTests'!

!GDBDataTest methodsFor: 'helper' stamp: 'lacm 11/13/2014 13:09'!
conferencesCollection
	^ GDBClientController databaseConference.! !

!GDBDataTest methodsFor: 'helper' stamp: 'lacm 11/13/2014 13:10'!
godDataCollection
	^ GDBClientController database.! !

!GDBDataTest methodsFor: 'initialize-release' stamp: 'lacm 11/14/2014 13:52'!
setUp	
	GDBClientController initializeSession.
	GDBClientController createDatabase.
	Transcript show: 'Starting Test'; cr.! !

!GDBDataTest methodsFor: 'initialize-release' stamp: 'lacm 11/14/2014 14:09'!
tearDown
	"comment stating purpose of message"
	Transcript show: 'Finishing Test'; cr.
	GDBClientController resetAllDatabase.
	GDBClientController release.



	
	! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/13/2014 13:11'!
testAddANoGodData
	|aNotGODData|
	aNotGODData :=	'Just a string'.	
	self should:[GDBClientController add: aNotGODData] raise: GDBDataMustBeAnGODData .
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/15/2014 19:28'!
testAddConferencesDataIsSaved
	|myKeywords myImportantDates myVenue myConference myCollection|
		
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.
										
	myCollection := OrderedCollection new add: myConference; yourself.

	GDBClientController saveConferences: myCollection.	
	GDBClientController release.
	
	self should:[self conferencesCollection size = 1].
	
	GDBClientController initializeSession.! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/18/2014 20:53'!
testAddDuplicatedGODData
	|myGODData|
		
	myGODData:=	GODData new author:'author A'; title: 'title A'; yourself.
	GDBClientController add: myGODData.
	
	self should:[GDBClientController add: myGODData] raise: GODDataAlreadyExistsInTheDatabase.! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/15/2014 19:28'!
testAddGODDataIsSaved
	|retrievedLastGODData myGODData|			
	
	myGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GDBClientController add: myGODData.		
	GDBClientController release.		
			
	self should: [self godDataCollection size = 1].	
	retrievedLastGODData:= self godDataCollection detectMax:[:each | each id].	
	self should: [retrievedLastGODData id > 0]. 
	GDBClientController initializeSession.! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/18/2014 20:54'!
testAddGODDataWithoutAuthor
	|myGODData|
		
	myGODData:=	GODData new title: 'title A'; yourself.
	
	self should:[GDBClientController add: myGODData] raise: GODDataAuthorMustContainsSomeInformation .! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/12/2014 16:37'!
testAddGODDataWithoutTitle
	|aGODData|
	aGODData :=	GODData new author: 'autor A'; yourself.
	self should:[GDBClientController add: aGODData] raise: GODDataTitleMustContainsSomeInformation .! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/12/2014 16:37'!
testGetAll
	| a b c collection|
	a := GODData new author: 'author A'; title: 'title A'; yourself.
	b := GODData new author: 'author A'; title: 'title B'; yourself.
	c := GODData new author: 'author B'; title: 'title A'; yourself.

	GDBClientController add: a; add: b; add: c.
	collection :=  GDBClientController getAll.
	self should: [collection size = 3].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/19/2014 21:16'!
testLoadConferencesData
	|retrievedCollection myKeywords myImportantDates myVenue myConference myCollection|
		
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.
										
	myCollection := OrderedCollection new add: myConference; yourself.

	GDBClientController saveConferences: myCollection.	
	GDBClientController release.
	
	GDBClientController initializeSession.
	retrievedCollection:= GDBClientController loadConferences.	
		
	self should:[retrievedCollection size = 1].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/18/2014 18:11'!
testRemoveGODDataIsSaved
	|removedGODData|
       removedGODData:= GODData new author: 'author B';
										  title: 'title B' ;
										  yourself.		
	GDBClientController add: removedGODData.
	
	self should: [self godDataCollection size = 1].
	
	GDBClientController remove: removedGODData.	
	
	GDBClientController release.
	
	self should:[self godDataCollection size = 0].
	GDBClientController initializeSession.! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/14/2014 15:56'!
testRepositoryEmptyDatabase
	
	self should: [self godDataCollection size = 0].
	self should: [self conferencesCollection size = 0].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/15/2014 19:30'!
testResetAllDatabase
	|myGODData myKeywords myImportantDates myVenue myConference myCollection|
	"saving a GODData object"
	myGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GDBClientController add: myGODData.		
		
	"saving a collection of GCConference objects"
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.										
	myCollection := OrderedCollection new add: myConference; yourself.
	GDBClientController saveConferences: myCollection.		
	
	GDBClientController release.
	self should: [self godDataCollection size = 1].				
	self should:[self conferencesCollection size = 1].
	
	GDBClientController initializeSession.
	GDBClientController resetAllDatabase.
	
	self should:[self conferencesCollection size = 0].
	self should:[self godDataCollection size = 0].
	
	! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/15/2014 19:31'!
testResetConferencesData
	|myGODData myKeywords myImportantDates myVenue myConference myCollection|
	"saving a GODData object"
	myGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GDBClientController add: myGODData.		
		
	"saving a collection of GCConference objects"
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.										
	myCollection := OrderedCollection new add: myConference; yourself.
	GDBClientController saveConferences: myCollection.		

	GDBClientController release.			
	self should: [self godDataCollection size = 1].				
	self should:[self conferencesCollection size = 1].
	
	GDBClientController initializeSession.
	GDBClientController resetConferenceData.
	
	self should:[self conferencesCollection size = 0].
	self should:[self godDataCollection size = 1].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/15/2014 19:31'!
testResetGODData
	|myGODData myKeywords myImportantDates myVenue myConference myCollection|
	"saving a GODData object"
	myGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GDBClientController add: myGODData.		
		
	"saving a collection of GCConference objects"
	myKeywords:= Set new add: 'neural'; add: 'genetic'; yourself.
	myImportantDates:= GCImportantDates new deadlineDate:'24 mar 14';
											startDate: '20 abr 14';
											endDate: '25 abr 14'; yourself.
	myVenue:= GCVenue new city: 'Holywood'; country: 'USA'; yourself.
	myConference := GCConference new   acronym:'aia'; 
										name:'Artificial Intelligence and Applications'; 
										keywords: myKeywords;
										url: 'http://conferences';
										importantDates: myImportantDates;
										venue: myVenue;
										yourself.										
	myCollection := OrderedCollection new add: myConference; yourself.
	GDBClientController saveConferences: myCollection.		

	GDBClientController release.			
	self should: [self godDataCollection size = 1].				
	self should:[self conferencesCollection size = 1].
	
	GDBClientController initializeSession.
	GDBClientController resetData.
	
	self should:[self conferencesCollection size = 1].
	self should:[self godDataCollection size = 0].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/18/2014 18:37'!
testSearchAuthor
	| a b c collection|
	a := GODData new author: 'one author A'; title: 'one title A'; yourself.
	b := GODData new author: 'other author A'; title: 'other title B'; yourself.
	c := GODData new author: 'my favorite author'; title: 'my favorite title'; yourself.

	GDBClientController add: a; add: b; add: c.

	collection :=  GDBClientController searchAuthor: 'author'.
	self should: [collection size = 3].

	collection :=  GDBClientController searchAuthor: 'favorite'.
	self should: [collection size = 1].

	collection :=  GDBClientController searchAuthor: 'author B'.
	self should: [collection size = 0].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/19/2014 22:26'!
testSearchByAuthor
	| a b c  collection|
	a := GODData new author: 'author A'; title: 'title A'; yourself.
	b := GODData new author: 'author A'; title: 'title B'; yourself.
	c := GODData new author: 'author B'; title: 'title A'; yourself.

	GDBClientController add: a; add: b; add: c.
	
	collection:=GDBClientController searchByAuthor: 'author A'.

	self should: [collection size = 2].
	
	collection:=GDBClientController searchByAuthor: 'author'.

	self should: [collection size = 0].! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/19/2014 22:20'!
testSearchById
	| a b c  aGODData|
	a := GODData new author: 'author A'; title: 'title A'; yourself.
	b := GODData new author: 'author A'; title: 'title B'; yourself.
	c := GODData new author: 'author B'; title: 'title A'; yourself.

	GDBClientController add: a; add: b; add: c.
	
	aGODData:=GDBClientController searchById: 1.

	self should: [aGODData id = 1].
	self should: [aGODData author = 'author A'].
	self should: [aGODData title = 'title A'].! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/19/2014 22:25'!
testSearchByTitle
	| a b c  collection|
	a := GODData new author: 'author A'; title: 'title A'; yourself.
	b := GODData new author: 'author A'; title: 'title B'; yourself.
	c := GODData new author: 'author B'; title: 'title A'; yourself.

	GDBClientController add: a; add: b; add: c.
	
	collection:=GDBClientController searchByTitle: 'title B'.

	self should: [collection size = 1].! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/12/2014 16:46'!
testSearchFor
	| a b c collection aBlock|
	a := GODData new author: 'author A'; title: 'title A'; yourself.
	b := GODData new author: 'author A'; title: 'title B'; yourself.
	c := GODData new author: 'author B'; title: 'title A'; yourself.

	GDBClientController add: a; add: b; add: c.
	aBlock := [:obj | obj author = 'author A'].
	collection :=  GDBClientController searchFor: aBlock.
	self should: [collection size = 2].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/18/2014 18:59'!
testSearchTitle
	| a b c collection|
	a := GODData new author: 'one author A'; title: 'one title A'; yourself.
	b := GODData new author: 'other author A'; title: 'other title B'; yourself.
	c := GODData new author: 'my favorite author'; title: 'my favorite title'; yourself.

	GDBClientController add: a; add: b; add: c.

	collection :=  GDBClientController searchTitle: 'title'.
	self should: [collection size = 3].

	collection :=  GDBClientController searchTitle: 'other'.
	self should: [collection size = 1].

	collection :=  GDBClientController searchTitle: 'title C'.
	self should: [collection size = 0].
! !

!GDBDataTest methodsFor: 'tests' stamp: 'lacm 11/18/2014 19:05'!
testUpdateAGODDataObject
	|oldGODData newGODData myReader|
	"saving a oldGODData object"
	oldGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.		
	GDBClientController add: oldGODData.		

	myReader := GDBClientController searchAuthor: 'author A'.	
	self should:[myReader size = 1].
	myReader := nil.
	
	newGODData:=	 GODData new author: 'author B'; title: 'title A'; yourself.				
	GDBClientController update: oldGODData with: newGODData.
	
	GDBClientController release.
	self should: [self godDataCollection size = 1].							

	GDBClientController initializeSession.			

	myReader := GDBClientController searchAuthor: 'author B'.	
	self should:[myReader size = 1].
	
	myReader := GDBClientController searchAuthor: 'author A'.	
	self should:[myReader size = 0].! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/15/2014 20:54'!
testUpdateANoNewGodData
	|aNotGODData aOldGODData|
	aNotGODData :=	'Just a string'.	
	aOldGODData:= GODData new.		
	self should:[GDBClientController update: aOldGODData with: aNotGODData] raise: GDBDataMustBeAnGODData .
! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/15/2014 20:53'!
testUpdateANoOldGodData
	|aNotGODData aNewGODData|
	aNotGODData :=	'Just a string'.	
	aNewGODData:= GODData new.		
	self should:[GDBClientController update: aNotGODData with: aNewGODData] raise: GDBDataMustBeAnGODData .
! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/15/2014 21:03'!
testUpdateNewGODDataWithoutAuthor
	|oldGODData newGODData|
	
	oldGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.	
	newGODData:=	GODData new title: 'title B'; yourself.
		
	self should:[GDBClientController update: oldGODData with:newGODData] raise: GODDataAuthorMustContainsSomeInformation .! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/15/2014 20:49'!
testUpdateNewGODDataWithoutTitle
	|oldGODData newGODData|
	
	oldGODData:=	GODData new author: 'author A'; title: 'title A'; yourself.	
	newGODData:=	GODData new author: 'author B';  yourself.
		
	self should:[GDBClientController update: oldGODData with:newGODData] raise: GODDataTitleMustContainsSomeInformation .! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/15/2014 20:48'!
testUpdateOldGODDataWithoutAuthor
	|oldGODData newGODData|
	
	oldGODData:=	GODData new title: 'title A'; yourself.	
	newGODData:=	GODData new author: 'author A'; title: 'title B'; yourself.
		
	self should:[GDBClientController update: oldGODData with:newGODData] raise: GODDataAuthorMustContainsSomeInformation .! !

!GDBDataTest methodsFor: 'fail' stamp: 'lacm 11/15/2014 20:49'!
testUpdateOldGODDataWithoutTitle
	|oldGODData newGODData|
	
	oldGODData:=	GODData new author: 'author A'; yourself.	
	newGODData:=	GODData new author: 'author B'; title: 'title B'; yourself.
		
	self should:[GDBClientController update: oldGODData with:newGODData] raise: GODDataTitleMustContainsSomeInformation .! !
